@@ -84,14 +84,12 @@ class NestedResolvers(BaseModel):
             if i == 0:
                 if r.is_count and "__count" in edge:
                     # avoid not copying resolver and having it break. make SURE it is a count
-                    resolver_s = (
-                        f'{edge} := count(.{edge.split("__")[0]} {r.all_filters_str()})'
-                    )
+                    resolver_s = f'{edge} := count((select .{edge.split("__")[0]} {r.all_filters_str()}))'
                 else:
                     resolver_s = f"{edge}: {r.to_str()}"
             else:
                 if r.is_count and "__count in edge":
-                    resolver_s = f"{edge}{SEPARATOR}{i} := count(.{edge.split('__')[0]} {r.all_filters_str()})"
+                    resolver_s = f"{edge}{SEPARATOR}{i} := count((select .{edge.split('__')[0]} {r.all_filters_str()}))"
                 else:
                     resolver_s = (
                         f"{edge}{SEPARATOR}{i} := (select .{edge} {r.to_str()})"
