@@ -647,6 +647,10 @@ class Resolver(BaseModel, T.Generic[NodeType]):
                     val = list_or_set(resolver.parse_nested_obj(d) for d in nested_d)
                 else:
                     val = resolver.parse_nested_obj(nested_d)
+                    if val._used_resolver._limit == 1 and type(val) not in {list, set}:
+                        # for some reason, edgedb returns a limit of 1 as not a list, so make list if needed
+                        val = [val]
+
                 value_to_save = val
             edge_name = NestedResolvers.edge_from_field_name(field_name)
             node.cache.add(
